<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>AvancedQFile</name>
    <message>
        <location filename="../../AvancedQFile.cpp" line="26"/>
        <location filename="../../AvancedQFile.cpp" line="57"/>
        <location filename="../../AvancedQFile.cpp" line="88"/>
        <source>Not supported on this platform</source>
        <translation>이 플랫폼에서 지원되지 않습니다</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="40"/>
        <source>Last modified date is wrong</source>
        <translation>마지막 수정 날짜가 잘못되었습니다</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="71"/>
        <source>Last access date is wrong</source>
        <translation>마지막 엑세스 날짜가 잘못되었습니다</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="121"/>
        <source>Unknown error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="187"/>
        <source>Unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="133"/>
        <source>Path conversion error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="429"/>
        <location filename="../../CopyEngine.cpp" line="451"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="462"/>
        <location filename="../../CopyEngine.cpp" line="484"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Destination</source>
        <translation type="unfinished">대상</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="732"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1062"/>
        <location filename="../../CopyEngine.cpp" line="1065"/>
        <location filename="../../CopyEngine.cpp" line="1070"/>
        <location filename="../../CopyEngine.cpp" line="1074"/>
        <source>Ask</source>
        <translation type="unfinished">확인</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1063"/>
        <location filename="../../CopyEngine.cpp" line="1067"/>
        <location filename="../../CopyEngine.cpp" line="1071"/>
        <location filename="../../CopyEngine.cpp" line="1075"/>
        <source>Skip</source>
        <translation type="unfinished">건너뛰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1066"/>
        <source>Merge</source>
        <translation type="unfinished">합치기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1068"/>
        <location filename="../../CopyEngine.cpp" line="1080"/>
        <source>Rename</source>
        <translation type="unfinished">이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1072"/>
        <source>Put at the end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1076"/>
        <source>Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1077"/>
        <source>Overwrite if different</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1078"/>
        <source>Overwrite if newer</source>
        <translation type="unfinished">더 최신이면 덮어씌우기</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1079"/>
        <source>Overwrite if older</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1082"/>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1083"/>
        <source>Sequential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1084"/>
        <source>Parallel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="427"/>
        <location filename="../../CopyEngineFactory.cpp" line="430"/>
        <location filename="../../CopyEngineFactory.cpp" line="435"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <source>Ask</source>
        <translation type="unfinished">확인</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="428"/>
        <location filename="../../CopyEngineFactory.cpp" line="432"/>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Skip</source>
        <translation type="unfinished">건너뛰기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="431"/>
        <source>Merge</source>
        <translation type="unfinished">합치기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="433"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <source>Rename</source>
        <translation type="unfinished">이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <source>Put at the end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <source>Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <source>Overwrite if different</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="443"/>
        <source>Overwrite if newer</source>
        <translation type="unfinished">더 최신이면 덮어씌우기</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <source>Overwrite if older</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="447"/>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Sequential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Parallel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="54"/>
        <source>Error on folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="57"/>
        <source>Folder name</source>
        <translation type="unfinished">폴더 이름</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="137"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="144"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Error</source>
        <translation type="unfinished">오류</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="111"/>
        <source>%name% - copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="118"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Error</source>
        <translation type="unfinished">오류</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Try rename with using special characters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="30"/>
        <source>Exclusion filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="93"/>
        <source>Inclusion filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="105"/>
        <source>None = Include all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="93"/>
        <location filename="../../Filters.cpp" line="131"/>
        <source>Raw text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="96"/>
        <location filename="../../Filters.cpp" line="134"/>
        <source>Simplified regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="99"/>
        <location filename="../../Filters.cpp" line="137"/>
        <source>Perl&apos;s regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="107"/>
        <location filename="../../Filters.cpp" line="145"/>
        <source>Only on file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="110"/>
        <location filename="../../Filters.cpp" line="148"/>
        <source>Only on folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="116"/>
        <location filename="../../Filters.cpp" line="154"/>
        <location filename="../../Filters.cpp" line="216"/>
        <location filename="../../Filters.cpp" line="255"/>
        <source>Full match</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="57"/>
        <source>Folder already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="122"/>
        <source>%name% - copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="131"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Error</source>
        <translation type="unfinished">오류</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Try rename with using special characters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThread.cpp" line="1487"/>
        <location filename="../../ListThread.cpp" line="2419"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1494"/>
        <location filename="../../ListThread.cpp" line="2426"/>
        <source>Unable to save the transfer list: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1510"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1517"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1526"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1535"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1541"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1604"/>
        <source>Some errors have been found during the line parsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1612"/>
        <source>Unable to open the transfer list: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="142"/>
        <source>Unable to create the folder</source>
        <translation>폴더를 생성할 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="155"/>
        <source>The source folder don&apos;t exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="183"/>
        <source>Unable to temporary rename the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="206"/>
        <source>Unable to do the final real move the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="233"/>
        <source>Unable to move the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="93"/>
        <location filename="../../MkPath.cpp" line="276"/>
        <source>Unable to remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../ReadThread.cpp" line="59"/>
        <source>Internal error, please report it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="188"/>
        <source>Internal error reading the source file:block size out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="196"/>
        <location filename="../../ReadThread.cpp" line="420"/>
        <source>Unable to read the source file: </source>
        <translation>원본 파일 읽기 불가:</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="237"/>
        <location filename="../../ReadThread.cpp" line="468"/>
        <source>File truncated during the read, possible data change</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="39"/>
        <location filename="../../RenamingRules.cpp" line="62"/>
        <source>%1 - copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="43"/>
        <location filename="../../RenamingRules.cpp" line="73"/>
        <source>%1 - copy (%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="274"/>
        <source>Blacklisted folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="338"/>
        <source>%1 - copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="345"/>
        <source>%1 - copy (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="401"/>
        <source>%name% - copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="408"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="444"/>
        <source>This is not a folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="446"/>
        <source>The folder does exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="448"/>
        <source>The folder is not readable</source>
        <translation type="unfinished">폴더를 읽을 수 없습니다</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="459"/>
        <source>Problem with name encoding</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="244"/>
        <location filename="../../TransferThread.cpp" line="673"/>
        <location filename="../../TransferThread.cpp" line="745"/>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <source>File not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="346"/>
        <location filename="../../TransferThread.cpp" line="363"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="421"/>
        <location filename="../../TransferThread.cpp" line="444"/>
        <source>Internal error: Already opening</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="586"/>
        <source>Drive %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="588"/>
        <source>Unknown folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="592"/>
        <source>root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="645"/>
        <source>%name% - copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="652"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="711"/>
        <location filename="../../TransferThread.cpp" line="826"/>
        <source>The source file doesn&apos;t exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="751"/>
        <location filename="../../TransferThread.cpp" line="838"/>
        <source>Unable to do the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="787"/>
        <source>The source doesn&apos;t exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="832"/>
        <source>Another file exists at same place</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1134"/>
        <source>The checksums do not match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1224"/>
        <source>Internal error: The destination is not closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1239"/>
        <source>Internal error: The size transfered doesn&apos;t match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1250"/>
        <source>Internal error: The buffer is not empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <location filename="../../TransferThread.cpp" line="1333"/>
        <location filename="../../TransferThread.cpp" line="1348"/>
        <source>Unable to change the date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../WriteThread.cpp" line="83"/>
        <source>Path resolution error (Empty path)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="277"/>
        <source>Internal error, please report it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="680"/>
        <source>Unable to read the source file: </source>
        <translation type="unfinished">원본 파일 읽기 불가:</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="705"/>
        <source>File truncated during read, possible data change</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="53"/>
        <source>Move the whole folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="60"/>
        <source>Transfer the file rights</source>
        <translation type="unfinished">파일 권한 전송</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="70"/>
        <source>Keep the file date</source>
        <translation type="unfinished">파일 날짜 보존</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Autostart the transfer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="90"/>
        <location filename="../../copyEngineOptions.ui" line="110"/>
        <source>Less performance if checked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="113"/>
        <source>Follow the strict order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="139"/>
        <source>Error and collision</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="145"/>
        <source>When folder error</source>
        <translation type="unfinished">폴더 오류시</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="155"/>
        <source>When file error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="181"/>
        <source>When file collision</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="241"/>
        <source>When folder collision</source>
        <translation type="unfinished">폴더 충돌시</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="272"/>
        <source>Check if destination folder exists</source>
        <translation type="unfinished">대상 폴드 존재시 확인</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="279"/>
        <source>Renaming rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="299"/>
        <source>Delete partially transferred files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="312"/>
        <source>Rename the original destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="343"/>
        <source>Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="349"/>
        <source>Checksum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="358"/>
        <source>Only after error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="365"/>
        <source>Ignore if impossible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="382"/>
        <source>Verify checksums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="414"/>
        <source>Performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="420"/>
        <source>Parallel buffer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="427"/>
        <location filename="../../copyEngineOptions.ui" line="440"/>
        <location filename="../../copyEngineOptions.ui" line="453"/>
        <location filename="../../copyEngineOptions.ui" line="490"/>
        <location filename="../../copyEngineOptions.ui" line="559"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="469"/>
        <source>Block size</source>
        <translation type="unfinished">블럭 크기</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="476"/>
        <source>Sequential buffer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="483"/>
        <source>Enable OS buffer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="506"/>
        <source>OS buffer only if smaller than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="513"/>
        <source>Transfer algorithm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="552"/>
        <source>Parallelize if smaller than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="582"/>
        <source>Inode threads (unsafe &gt; 1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="589"/>
        <location filename="../../copyEngineOptions.ui" line="599"/>
        <source>More cpu, but better organisation on the disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="602"/>
        <source>Order the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="618"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="624"/>
        <source>Check the disk space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="634"/>
        <source>Use this folder when destination is not set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="646"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="668"/>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation>수정 날짜</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation type="unfinished">대상</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>아래에 놓기</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>재시도</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;건너뛰기</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>파일이 존재합니다</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>원본</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>대상</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation>수정 날짜</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>새 &amp;이름 제안</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;덮어씌우기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;건너뛰기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if newer</source>
        <translation>더 최신이면 덮어씌우기</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if older</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation>수정 날짜</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>새 &amp;이름 제안</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>&amp;이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>&amp;건너뛰기</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>원본</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>대상</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation>수정 날짜</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>폴더 이름</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>새 &amp;이름 제안</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>&amp;이름 바꾸기</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>합치기</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>건너뛰기</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>&amp;취소</translation>
    </message>
</context>
</TS>
